@@ -33,11 +33,11 @@
 #include <bluetooth/bluetooth.h>
 
 #include <glib.h>
+#include <btio/btio.h>
 
 #include "plugin.h"
 #include "log.h"
 #include "hcid.h"
-#include "btio.h"
 
 static GSList *plugins = NULL;
 
@@ -47,7 +47,7 @@ struct bluetooth_plugin {
 	struct bluetooth_plugin_desc *desc;
 };
 
-static gint compare_priority(gconstpointer a, gconstpointer b)
+static int compare_priority(gconstpointer a, gconstpointer b)
 {
 	const struct bluetooth_plugin *plugin1 = a;
 	const struct bluetooth_plugin *plugin2 = b;
@@ -84,19 +84,9 @@ static gboolean add_plugin(void *handle, struct bluetooth_plugin_desc *desc)
 	return TRUE;
 }
 
-static gboolean enable_plugin(const char *name, char **conf_disable,
-					char **cli_enable, char **cli_disable)
+static gboolean enable_plugin(const char *name, char **cli_enable,
+							char **cli_disable)
 {
-	if (conf_disable) {
-		for (; *conf_disable; conf_disable++)
-			if (g_pattern_match_simple(*conf_disable, name))
-				break;
-		if (*conf_disable) {
-			info("Excluding (conf) %s", name);
-			return FALSE;
-		}
-	}
-
 	if (cli_disable) {
 		for (; *cli_disable; cli_disable++)
 			if (g_pattern_match_simple(*cli_disable, name))
@@ -122,25 +112,18 @@ static gboolean enable_plugin(const char *name, char **conf_disable,
 
 #include "builtin.h"
 
-gboolean plugin_init(GKeyFile *config, const char *enable, const char *disable)
+gboolean plugin_init(const char *enable, const char *disable)
 {
 	GSList *list;
 	GDir *dir;
-	const gchar *file;
-	char **conf_disabled, **cli_disabled, **cli_enabled;
+	const char *file;
+	char **cli_disabled, **cli_enabled;
 	unsigned int i;
 
 	/* Make a call to BtIO API so its symbols got resolved before the
 	 * plugins are loaded. */
 	bt_io_error_quark();
 
-	if (config)
-		conf_disabled = g_key_file_get_string_list(config, "General",
-							"DisablePlugins",
-							NULL, NULL);
-	else
-		conf_disabled = NULL;
-
 	if (enable)
 		cli_enabled = g_strsplit_set(enable, ", ", -1);
 	else
@@ -154,8 +137,8 @@ gboolean plugin_init(GKeyFile *config, const char *enable, const char *disable)
 	DBG("Loading builtin plugins");
 
 	for (i = 0; __bluetooth_builtin[i]; i++) {
-		if (!enable_plugin(__bluetooth_builtin[i]->name, conf_disabled,
-						cli_enabled, cli_disabled))
+		if (!enable_plugin(__bluetooth_builtin[i]->name, cli_enabled,
+								cli_disabled))
 			continue;
 
 		add_plugin(NULL,  __bluetooth_builtin[i]);
@@ -173,7 +156,7 @@ gboolean plugin_init(GKeyFile *config, const char *enable, const char *disable)
 	while ((file = g_dir_read_name(dir)) != NULL) {
 		struct bluetooth_plugin_desc *desc;
 		void *handle;
-		gchar *filename;
+		char *filename;
 
 		if (g_str_has_prefix(file, "lib") == TRUE ||
 				g_str_has_suffix(file, ".so") == FALSE)
@@ -198,8 +181,7 @@ gboolean plugin_init(GKeyFile *config, const char *enable, const char *disable)
 			continue;
 		}
 
-		if (!enable_plugin(desc->name, conf_disabled,
-						cli_enabled, cli_disabled)) {
+		if (!enable_plugin(desc->name, cli_enabled, cli_disabled)) {
 			dlclose(handle);
 			continue;
 		}
@@ -222,7 +204,6 @@ start:
 		plugin->active = TRUE;
 	}
 
-	g_strfreev(conf_disabled);
 	g_strfreev(cli_enabled);
 	g_strfreev(cli_disabled);
 
